function [thresholds, values] = generate_thresholds(configuration, n_configurations, n_repetitions, n_iterations)
%GENERATE_THRESHOLDS generate the thresholds for a given set of
%   configurations
%   Input:
%       configuration   : cell array with configurations generated by
%           GENERATE_CONFIGURATIONS()
%       n_configurations: number of considered configurations
%       n_repetitions: number of independent repetition of the experiments
%       n_iterations: length of each experiments
%
%   Output:
%       thresholds: cell array with thresholds for the considered
%           configurations, repetitions and iterations
%       values    : cell array with values for the considered arms for the
%           considered configurations
%

%   Copyright 2015 Paladino, S. and Trovo', F., Politecnico di Milano

thresholds = zeros(n_configurations,n_repetitions,n_iterations);
values = cell(n_configurations,1);

for cc = 1 : n_configurations
    temp_conf = configuration(cc);
    for rr = 1:n_repetitions
        if strcmp(temp_conf.pd.DistName,'normal')
            thresholds(cc,rr,:) = random(temp_conf.pd,1,n_iterations);
            values{cc} = (1-cdf(temp_conf.pd,temp_conf.arms)) .* temp_conf.arms;
            
        elseif strcmp(temp_conf.pd.DistName,'gaussian mixture distribution')
            thresholds(cc,rr,:) = (random(temp_conf.pd,n_iterations))';
            values{cc} = ((1-cdf(temp_conf.pd,temp_conf.arms)) .* temp_conf.arms)';
        end
    end
end